@@ -82,7 +82,8 @@ GeomInteractiveSegment <- ggproto("GeomSegment", Geom,
 		},
 
 		required_aes = c("x", "y", "xend", "yend"),
-		default_aes = aes(colour = "black", size = 0.5, linetype = 1, alpha = NA),
+		default_aes = aes(colour = "black", size = 0.5, linetype = 1, alpha = NA,
+		                  tooltip = NULL, onclick = NULL, data_id = NULL),
 
 		draw_key = draw_key_path
 )
