@@ -5,8 +5,9 @@
 #' @importFrom grDevices dev.off
 #' @importFrom xml2 read_xml xml_find_all xml_text xml_ns
 #' @importFrom xml2 xml_remove xml_attr xml_attr<-
+#' @importFrom uuid UUIDgenerate
 
-#' @title ggiraph
+#' @title create a ggiraph object
 #'
 #' @description Create an interactive graphic to be used in a web browser.
 #'
@@ -16,9 +17,20 @@
 #' aesthetics are understood: \code{tooltip}, \code{onclick}
 #' and \code{data_id}.
 #'
-#' Tooltips can be displayed when mouse is over graphical elements. On click
-#' actions can be set with javascript instructions. If id are associated with points,
-#' they get animated when mouse is over and can be selected when used in shiny apps.
+#' Tooltips can be displayed when mouse is over graphical elements.
+#'
+#' If id are associated with points, they get animated when mouse is
+#' over and can be selected when used in shiny apps.
+#'
+#' On click actions can be set with javascript instructions. This option
+#' should not be used simultaneously with selections in Shiny
+#' applications as both features are "on click" features.
+#'
+#' When \code{zoom_max} is set, "zoom activate", "zoom desactivate" and
+#' "zoom init" buttons are available in a toolbar.
+#'
+#' When \code{selection} is set to multiple (in Shiny applications), lasso
+#' selection and lasso anti-selections buttons are available in a toolbar.
 #'
 #' @param code Plotting code to execute
 #' @param ggobj ggplot objet to print. argument \code{code} will
@@ -35,16 +47,14 @@
 #' @param selection_type row selection mode ("single", "multiple", "none")
 #'  when widget is in a Shiny application.
 #' @param selected_css css to apply when element is selected (shiny only).
-#' @param width widget width ratio (0 < width <= 1)
-#' @param flexdashboard should be TRUE when used within a flexdashboard to
-#' ensure svg will fit in boxes.
+#' @param width,flexdashboard deprecated
 #' @param ... arguments passed on to \code{\link[rvg]{dsvg}}
 #' @examples
 #' # ggiraph simple example -------
 #' @example examples/geom_point_interactive.R
 #' @export
 ggiraph <- function(code, ggobj = NULL,
-	pointsize = 12, width = 0.7,
+	pointsize = 12, width = NULL,
 	width_svg = 6, height_svg = 6,
 	tooltip_extra_css,
 	hover_css,
@@ -53,17 +63,20 @@ ggiraph <- function(code, ggobj = NULL,
 	tooltip_offy = 0,
 	zoom_max = 1,
 	selection_type = "multiple",
-	selected_css, flexdashboard = FALSE,
+	selected_css, flexdashboard = NULL,
 	...) {
 
   if( missing( tooltip_extra_css ))
     tooltip_extra_css <- "padding:5px;background:black;color:white;border-radius:2px 2px 2px 2px;"
   if( missing( hover_css ))
-    hover_css <- "fill:orange;"
+    hover_css <- "fill:orange;stroke:gray;"
   if( missing( selected_css ))
-    selected_css = "fill:orange;"
-
+    selected_css <- hover_css
 
+  if( !is.null(width) )
+    warning("argument 'width' is deprecated and will have no effect.")
+  if( !is.null(flexdashboard) )
+    warning("argument 'flexdashboard' is deprecated and will have no effect.")
 
   stopifnot(selection_type %in% c("single", "multiple", "none"))
   stopifnot(is.numeric(tooltip_offx))
@@ -102,7 +115,7 @@ ggiraph <- function(code, ggobj = NULL,
 	xml_remove(scr)
   xml_attr(data, "width") <- NULL
   xml_attr(data, "height") <- NULL
-
+  xml_attr(data, "class") <- "svg-inline-container"
 
 	if( grepl(x = tooltip_extra_css, pattern = "position[ ]*:") )
 	  stop("please, do not specify position in tooltip_extra_css, this parameter is managed by ggiraph.")
@@ -110,20 +123,68 @@ ggiraph <- function(code, ggobj = NULL,
 	  stop("please, do not specify pointer-events in tooltip_extra_css, this parameter is managed by ggiraph.")
 
 
-	x = list( html = HTML( as.character(data) ), code = js,
-	          tooltip_extra_css = tooltip_extra_css, hover_css = hover_css, selected_css = selected_css,
-	          tooltip_opacity = tooltip_opacity, tooltip_offx = tooltip_offx, tooltip_offy = tooltip_offy,
-	          zoom_max = zoom_max,
-	          selection_type = selection_type,
-	          ratio = width_svg / height_svg, flexdashboard = flexdashboard, width = width
-	          )
 	unlink(path)
+	scale_ <- 100
+	ratio_ <- width_svg / height_svg
+
+	style_container <- paste0(
+	  sprintf("%s:%.0f%%;", "padding-top", 1 / ratio_ * scale_),
+	  sprintf("%s:%.0f%%;", "width", scale_) )
+  id <- gsub("-", "", paste0("uid", UUIDgenerate() ))
+
+  dep_dir <- tempfile()
+  dir.create(dep_dir)
+
+  init_prop_name <- paste0("init_prop_", id)
+  array_selected_name <- paste0("array_selected_", id)
+  zoom_name <- paste0("zoom_", id)
+  lasso_name <- paste0("lasso_", id)
+  class_selected_name <- paste0("clicked_", id)
+  widget_id <- paste0("widget_", id)
+  ratio_id <- paste0("ratio_", id)
+
+
+  js <- paste0("function ", init_prop_name, "(){", js, "};")
+  js <- paste0(js, paste0("var ", array_selected_name, " = [];") )
+  js <- paste0(js, sprintf("var %s = %.3f;", ratio_id, ratio_) )
+  js <- paste0(js, sprintf("var %s = d3.zoom().scaleExtent([%.02f, %.02f]);", zoom_name, 1, zoom_max) )
+  js <- paste0(js, sprintf("var %s = d3.lasso();", lasso_name) )
+  js <- paste0(js, sprintf("var %s = '';", widget_id) )
+
+  js_file <- file.path(dep_dir, paste0("scripts_", id, ".js"))
+  cat(js, file = js_file)
+
+  css <- paste0("div.tooltip_", id,
+                " {position:absolute;pointer-events:none;z-index:999;",
+                tooltip_extra_css, "}\n",
+                ".cl_data_id_", id, ":{}.cl_data_id_", id, ":hover{", hover_css, "}\n",
+                ".", class_selected_name, "{", selected_css, "}"
+                )
+
+  dep <- htmlDependency(id, "0.0.1", src = dep_dir, script = basename(js_file) )
+  ui_div_ <- ui_div(id = id, zoomable = (zoom_max > 1),
+                    letlasso = selection_type %in% "multiple",
+                    array_selected_name, class_selected_name )
+  html_ <- paste0("<div id='", id, "' class='container' style='", style_container, "'>",
+                  as.character(data), ui_div_,
+                  "<style>", css, "</style>",
+                  "</div>")
+  x = list( html = html_, uid = id,
+            funname = init_prop_name,
+            sel_array_name = array_selected_name,
+            selected_class = class_selected_name,
+            tooltip_opacity = tooltip_opacity,
+            tooltip_offx = tooltip_offx, tooltip_offy = tooltip_offy,
+            zoom_max = zoom_max,
+            selection_type = selection_type)
+
+  htmlwidgets::createWidget(dependencies = list(dep),
+                            name = 'ggiraph', x = x, package = 'ggiraph',
+                            sizingPolicy = sizingPolicy(knitr.figure = FALSE,
+                                                        defaultWidth = "90%",
+                                                        defaultHeight = "500px")
+  )
 
-	# create widget
-	htmlwidgets::createWidget(
-			name = 'ggiraph', x = x, package = 'ggiraph',
-			sizingPolicy = sizingPolicy(knitr.figure = FALSE, defaultWidth = "70%", defaultHeight = "auto")
-	)
 }
 
 #' @title Create a ggiraph output element
@@ -146,16 +207,7 @@ ggiraph <- function(code, ggobj = NULL,
 #' @export
 ggiraphOutput <- function(outputId, width = "100%", height = "500px"){
 
-  msger <- sprintf(
-    "Shiny.addCustomMessageHandler('%s',function(message) {var varname = '%s';d3.selectAll('#%s *[data-id]').classed('selected_%s', false);d3.selectAll(message).each(function(d, i) {d3.selectAll('#%s *[data-id=\"'+ message[i] + '\"]').classed('selected_%s', true);});window[varname] = message;Shiny.onInputChange(varname, window[varname]);});",
-    paste0(outputId, "_set"),
-    paste0(outputId, "_selected"),
-    outputId, outputId, outputId, outputId)
-
-  div(
-    singleton( tags$head(tags$script(msger)) ),
-	  shinyWidgetOutput(outputId, 'ggiraph', package = 'ggiraph', width = width, height = height)
-  )
+  shinyWidgetOutput(outputId, 'ggiraph', package = 'ggiraph', width = width, height = height)
 }
 
 #' @title Reactive version of ggiraph object
@@ -177,3 +229,12 @@ renderggiraph <- function(expr, env = parent.frame(), quoted = FALSE) {
 	if (!quoted) { expr <- substitute(expr) } # force quoted
 	shinyRenderWidget(expr, ggiraphOutput, env, quoted = TRUE)
 }
+
+
+
+
+
+
+
+
+
